<?php
namespace Folha\Logic\ESocial\Eventos\Data;
use Folha\Logic\ESocial\GerenciaEnvios;

/**
 * Classe provedora do datasource utilizado para a geracao do evento S-1030 - Tabela de Cargos.
 *
 * @package Folha\Logic\ESocial\Eventos\Data
 * @author paulopereira
 **/
class S1030
{

    /**
     * Retorna os dados que serao utilizado para a geracao do(s) arquivo(s) do evento S-1030, tabela de cargos.
     *
     * @param $dsordem                 Define as possíveis formas de filtro utilizadas pela tela de envio de eventos  
     *                                 do e-Social. Pode ser ALFABETICA, MATRICULA, DATA_ADMISSAO e ESTRUTURA. Para este
     *                                 evento, em especial, somente o filtro por ESTRUTURA poderá será relevante.
     * @param $limiteInferior          Limite inferior do filtro aplicado. O significado dos dados trazidos neste campo
     *                                 deverao variar, conforme o parametro dsordem.
     * @param $limiteSuperior          Limite superior do filtro aplicado. O significado dos dados trazidos neste campo
     *                                 deverao variar, conforme o parametro dsordem.
     * @param $inicioPeriodo           Inicio do intervalo que deverá ter os eventos gerados. Somente será utilizado se
     *                                 o parametro "$utilizaIntervaloDeDatas" for igual a "true". 
     * @param $fimPeriodo              Final do intervalo que deverá ter os eventos gerados. Somente será utilizado se
     *                                 o parametro "$utilizaIntervaloDeDatas" for igual a "true".
     * @param $utilizaIntervaloDeDatas Verifica se o dataset deve ser filtrado pelos campos de intervalo da tela de  
     *                                 envio de eventos e-Social, ou se devem enviados os arquivos alterados depois do 
     *                                 ultimo envio.
     * @param $nrorg                   Nrorg.
     * @param $versaoHRM               Versao do sistema HRM utilizado para a geracao dos relatorios.
     *
     * @return array
     * @author felipesantos
     **/
    public static function getDataSource($dsordem, $limiteInferior, $limiteSuperior, $inicioPeriodo, $fimPeriodo, 
                                         $utilizaIntervaloDeDatas, $nrorg, $versaoHRM, $versaoEsocial, $tpAmbiente)
    {
        $S1030 = \Folha\Repositories\GpeEsocialRegistro::dataSetEsocial_S1030(
            $dsordem, $limiteInferior, $limiteSuperior, $inicioPeriodo, $fimPeriodo, 
            $utilizaIntervaloDeDatas, $nrorg, $versaoHRM, $versaoEsocial, $tpAmbiente
        );

        foreach ($S1030 as &$row) {
            /*Verifica pelo log de envios se o evento/chave já foi enviado para definir ser é um envio de inclusão ou alteração*/
            $operacao = new GerenciaEnvios('S-1030', $versaoEsocial, $row['CHAVE'], null, $nrorg);
            $operacao = $operacao->validaTipoEnvio();

            $row['INCLUSAO'] = $operacao['INCLUSAO'];
            $row['ALTERACAO'] = $operacao['ALTERACAO'];
        }

        return $S1030;
    }

}